cut

Function cut 

pub fn cut(
    model: &mut Model,
    a: &Shape,
    b: &Shape,
    tol: Tolerances,
) -> OgeomResult<Built>
The first solid with the second removed.

The pieces of b that close the cut into a’s material bound the removed volume from b’s side, so they join the result with their material side flipped.

Errors

As fuse.