make_periodic

Function make_periodic 

pub fn make_periodic(
    model: &mut Model,
    shape: &Shape,
    step: Vector,
    count: usize,
    tol: Tolerances,
) -> OgeomResult<Built>
A shape repeated count times along a direction at a period and fused into one: the periodic pattern as a composition of what exists.

Errors

As fuse, plus an unusable count or period.